summaryrefslogtreecommitdiffstats
path: root/kivio/plugins/kivioselecttool/tool_select.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /kivio/plugins/kivioselecttool/tool_select.cpp
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kivio/plugins/kivioselecttool/tool_select.cpp')
-rw-r--r--kivio/plugins/kivioselecttool/tool_select.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kivio/plugins/kivioselecttool/tool_select.cpp b/kivio/plugins/kivioselecttool/tool_select.cpp
index b6c24c57..6117cf61 100644
--- a/kivio/plugins/kivioselecttool/tool_select.cpp
+++ b/kivio/plugins/kivioselecttool/tool_select.cpp
@@ -247,7 +247,7 @@ bool SelectTool::startRubberBanding(const TQPoint &pos)
canvas->activePage()->unselectAllStencils();
canvas->startRectDraw( pos, KivioCanvas::Rubber );
- canvas->tqrepaint();
+ canvas->repaint();
return true;
}
@@ -299,7 +299,7 @@ bool SelectTool::startDragging(const TQPoint &pos, bool onlySelected)
// Create a new painter object
canvas->beginUnclippedSpawnerPainter();
// Build the list of old tqgeometry
KivioSelectDragData *pData;
m_lstOldGeometry.clear();
pStencil = canvas->activePage()->selectedStencils()->first();
@@ -365,7 +365,7 @@ bool SelectTool::startCustomDragging(const TQPoint &pos, bool selectedOnly )
m_customDragOrigPoint = pStencil->customIDPoint(m_customDragID);
view()->canvasWidget()->setShowConnectorTargets(true);
- view()->canvasWidget()->tqrepaint();
+ view()->canvasWidget()->repaint();
// Create a new painter object
canvas->beginUnclippedSpawnerPainter();
@@ -491,7 +491,7 @@ void SelectTool::continueRubberBanding(const TQPoint &pos)
* Continues the dragging process of a stencil (moving)
*
* How does this work? Initially we create a list of all the original
* tqgeometry of all the selected stencils. We use that to calculate delta
* movements and snap them to the grid.
*/
void SelectTool::continueDragging(const TQPoint &pos, bool ignoreGridGuides)
@@ -512,7 +512,7 @@ void SelectTool::continueDragging(const TQPoint &pos, bool ignoreGridGuides)
canvas->drawSelectedStencilsXOR();
} else {
canvas->activePage()->setPaintSelected(false);
- canvas->tqrepaint();
+ canvas->repaint();
m_firstTime = false;
}
@@ -628,7 +628,7 @@ void SelectTool::continueCustomDragging(const TQPoint &pos)
canvas->drawStencilXOR(m_pCustomDraggingStencil);
} else {
m_pCustomDraggingStencil->setHidden(true);
- canvas->tqrepaint();
+ canvas->repaint();
m_firstTime = false;
}
}
@@ -641,7 +641,7 @@ void SelectTool::continueCustomDragging(const TQPoint &pos)
if(m_pCustomDraggingStencil->type() != kstConnector){
canvas->drawStencilXOR(m_pCustomDraggingStencil);
} else {
- view()->canvasWidget()->tqrepaint();
+ view()->canvasWidget()->repaint();
}
view()->updateToolBars();
@@ -674,7 +674,7 @@ void SelectTool::continueResizing(const TQPoint &pos, bool ignoreGridGuides)
if( !pData )
{
- kdDebug(43000) << "SelectTool::continueResizing() - Original tqgeometry not found" << endl;
+ kdDebug(43000) << "SelectTool::continueResizing() - Original geometry not found" << endl;
return;
}
@@ -687,7 +687,7 @@ void SelectTool::continueResizing(const TQPoint &pos, bool ignoreGridGuides)
canvas->drawStencilXOR( m_pResizingStencil );
} else {
m_pResizingStencil->setHidden(true);
- canvas->tqrepaint();
+ canvas->repaint();
m_firstTime = false;
}
@@ -1050,7 +1050,7 @@ void SelectTool::endDragging(const TQPoint&)
canvas->drawSelectedStencilsXOR();
canvas->endUnclippedSpawnerPainter();
// Clear the list of old tqgeometry
m_lstOldGeometry.clear();
}
@@ -1077,7 +1077,7 @@ void SelectTool::endCustomDragging(const TQPoint&)
canvas->endUnclippedSpawnerPainter();
canvas->setShowConnectorTargets(false);
- canvas->tqrepaint();
+ canvas->repaint();
}
void SelectTool::endResizing(const TQPoint&)
@@ -1200,7 +1200,7 @@ void SelectTool::keyPress(TQKeyEvent* e)
// Create a new painter object
canvas->beginUnclippedSpawnerPainter();
// Build the list of old tqgeometry
KivioSelectDragData *pData;
m_lstOldGeometry.clear();
KivioStencil* pStencil = canvas->activePage()->selectedStencils()->first();
@@ -299,7 +299,7 @@ bool SelectTool::startDragging(const TQPoint &pos, bool onlySelected)
// Create a new painter object
canvas->beginUnclippedSpawnerPainter();
- // Build the list of old tqgeometry
+ // Build the list of old geometry
KivioSelectDragData *pData;
m_lstOldGeometry.clear();
@@ -491,7 +491,7 @@ void SelectTool::continueRubberBanding(const TQPoint &pos)
*
* How does this work? Initially we create a list of all the original
- * tqgeometry of all the selected stencils. We use that to calculate delta
+ * geometry of all the selected stencils. We use that to calculate delta
* movements and snap them to the grid.
*/
@@ -1050,7 +1050,7 @@ void SelectTool::endDragging(const TQPoint&)
canvas->drawSelectedStencilsXOR();
canvas->endUnclippedSpawnerPainter();
- // Clear the list of old tqgeometry
+ // Clear the list of old geometry
m_lstOldGeometry.clear();
}
@@ -1200,7 +1200,7 @@ void SelectTool::keyPress(TQKeyEvent* e)
// Create a new painter object
canvas->beginUnclippedSpawnerPainter();
- // Build the list of old tqgeometry
+ // Build the list of old geometry
KivioSelectDragData *pData;
m_lstOldGeometry.clear();